@@ -30,7 +30,10 @@ def run_ml_cli_pipeline(args, config_path, ml_cli_template_path):
         with open(ml_cli_template_path) as mlcli_file:
             mlcli_template = mlcli_file.read()
     else:
-        mlcli_template = json.loads(mlcli_template_json)
+        mlcli_template = mlcli_template_json
+
+    print("mlcli_template", mlcli_template)
+    print("datasets", config["datasets"])
 
     run_ml_cli_pipeline_from(config, config_aml_path, mlcli_template, build_id, build_tags, skip_train_execution)
 
